# bimdata-api-client
BIMData API is a tool to interact with your models stored on BIMData’s servers.
    Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1 (v1)
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://bimdata.io/](https://bimdata.io/)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import bimdata_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import bimdata_api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import bimdata_api_client
from pprint import pprint
from bimdata_api_client.api import bcf_api
from bimdata_api_client.model.bcf_project import BcfProject
from bimdata_api_client.model.bcf_project_request import BcfProjectRequest
from bimdata_api_client.model.coloring import Coloring
from bimdata_api_client.model.comment import Comment
from bimdata_api_client.model.comment_request import CommentRequest
from bimdata_api_client.model.component import Component
from bimdata_api_client.model.detailed_extensions import DetailedExtensions
from bimdata_api_client.model.extensions import Extensions
from bimdata_api_client.model.full_topic import FullTopic
from bimdata_api_client.model.full_topic_request import FullTopicRequest
from bimdata_api_client.model.label import Label
from bimdata_api_client.model.label_request import LabelRequest
from bimdata_api_client.model.patched_bcf_project_request import PatchedBcfProjectRequest
from bimdata_api_client.model.patched_comment_request import PatchedCommentRequest
from bimdata_api_client.model.patched_full_topic_request import PatchedFullTopicRequest
from bimdata_api_client.model.patched_label_request import PatchedLabelRequest
from bimdata_api_client.model.patched_priority_request import PatchedPriorityRequest
from bimdata_api_client.model.patched_stage_request import PatchedStageRequest
from bimdata_api_client.model.patched_topic_request import PatchedTopicRequest
from bimdata_api_client.model.patched_topic_status_request import PatchedTopicStatusRequest
from bimdata_api_client.model.patched_topic_type_request import PatchedTopicTypeRequest
from bimdata_api_client.model.patched_viewpoint_request import PatchedViewpointRequest
from bimdata_api_client.model.priority import Priority
from bimdata_api_client.model.priority_request import PriorityRequest
from bimdata_api_client.model.self_bcf_user import SelfBcfUser
from bimdata_api_client.model.stage import Stage
from bimdata_api_client.model.stage_request import StageRequest
from bimdata_api_client.model.topic import Topic
from bimdata_api_client.model.topic_request import TopicRequest
from bimdata_api_client.model.topic_status import TopicStatus
from bimdata_api_client.model.topic_status_request import TopicStatusRequest
from bimdata_api_client.model.topic_type import TopicType
from bimdata_api_client.model.topic_type_request import TopicTypeRequest
from bimdata_api_client.model.viewpoint import Viewpoint
from bimdata_api_client.model.viewpoint_request import ViewpointRequest
from bimdata_api_client.model.visibility import Visibility
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = bimdata_api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'

# Configure OAuth2 access token for authorization: BIMData_Connect
configuration = bimdata_api_client.Configuration(
    host = "http://localhost"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# Configure OAuth2 access token for authorization: BIMData_Connect
configuration = bimdata_api_client.Configuration(
    host = "http://localhost"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# Configure API key authorization: Bearer
configuration.api_key['Bearer'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Bearer'] = 'Bearer'


# Enter a context with an instance of the API client
with bimdata_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = bcf_api.BcfApi(api_client)
    projects_pk = 1 # int | A unique integer value identifying this project.
topics_guid = "topics_guid_example" # str | 
comment_request = CommentRequest(
        guid="guid_example",
        date=dateutil_parser('1970-01-01T00:00:00.00Z'),
        author="author_example",
        comment="comment_example",
        viewpoint_guid="viewpoint_guid_example",
        reply_to_comment_guid="reply_to_comment_guid_example",
        modified_author="modified_author_example",
        viewpoint_temp_id=1,
    ) # CommentRequest |  (optional)

    try:
        # Create a comment
        api_response = api_instance.create_comment(projects_pk, topics_guid, comment_request=comment_request)
        pprint(api_response)
    except bimdata_api_client.ApiException as e:
        print("Exception when calling BcfApi->create_comment: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BcfApi* | [**create_comment**](docs/BcfApi.md#create_comment) | **POST** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments | Create a comment
*BcfApi* | [**create_extension_label**](docs/BcfApi.md#create_extension_label) | **POST** /bcf/2.1/projects/{projects_pk}/extension/label | Create a Label
*BcfApi* | [**create_extension_priority**](docs/BcfApi.md#create_extension_priority) | **POST** /bcf/2.1/projects/{projects_pk}/extension/priority | Create a Priority
*BcfApi* | [**create_extension_stage**](docs/BcfApi.md#create_extension_stage) | **POST** /bcf/2.1/projects/{projects_pk}/extension/stage | Create a Stage
*BcfApi* | [**create_extension_status**](docs/BcfApi.md#create_extension_status) | **POST** /bcf/2.1/projects/{projects_pk}/extension/status | Create a TopicStatus
*BcfApi* | [**create_extension_type**](docs/BcfApi.md#create_extension_type) | **POST** /bcf/2.1/projects/{projects_pk}/extension/type | Create a TopicType
*BcfApi* | [**create_full_topic**](docs/BcfApi.md#create_full_topic) | **POST** /bcf/2.1/projects/{projects_pk}/full-topic | Create a Topic with viewpoints and comments
*BcfApi* | [**create_topic**](docs/BcfApi.md#create_topic) | **POST** /bcf/2.1/projects/{projects_pk}/topics | Create a topic
*BcfApi* | [**create_viewpoint**](docs/BcfApi.md#create_viewpoint) | **POST** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints | Create a Viewpoint
*BcfApi* | [**delete_comment**](docs/BcfApi.md#delete_comment) | **DELETE** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments/{guid} | Delete a comment
*BcfApi* | [**delete_extension_label**](docs/BcfApi.md#delete_extension_label) | **DELETE** /bcf/2.1/projects/{projects_pk}/extension/label/{id} | Delete a Label
*BcfApi* | [**delete_extension_priority**](docs/BcfApi.md#delete_extension_priority) | **DELETE** /bcf/2.1/projects/{projects_pk}/extension/priority/{id} | Delete a Priority
*BcfApi* | [**delete_extension_stage**](docs/BcfApi.md#delete_extension_stage) | **DELETE** /bcf/2.1/projects/{projects_pk}/extension/stage/{id} | Delete a Stage
*BcfApi* | [**delete_extension_status**](docs/BcfApi.md#delete_extension_status) | **DELETE** /bcf/2.1/projects/{projects_pk}/extension/status/{id} | Delete a TopicStatus
*BcfApi* | [**delete_extension_type**](docs/BcfApi.md#delete_extension_type) | **DELETE** /bcf/2.1/projects/{projects_pk}/extension/type/{id} | Delete a TopicType
*BcfApi* | [**delete_topic**](docs/BcfApi.md#delete_topic) | **DELETE** /bcf/2.1/projects/{projects_pk}/topics/{guid} | Delete a topic
*BcfApi* | [**delete_viewpoint**](docs/BcfApi.md#delete_viewpoint) | **DELETE** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid} | Delete a Viewpoint
*BcfApi* | [**download_bcf_export**](docs/BcfApi.md#download_bcf_export) | **GET** /bcf/2.1/projects/{id}/export | Export project&#39;s topics in bcf-xml format
*BcfApi* | [**full_update_bcf_project**](docs/BcfApi.md#full_update_bcf_project) | **PUT** /bcf/2.1/projects/{id} | Update all fields of a BCF project
*BcfApi* | [**full_update_comment**](docs/BcfApi.md#full_update_comment) | **PUT** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments/{guid} | Update all fields of a comment
*BcfApi* | [**full_update_full_topic**](docs/BcfApi.md#full_update_full_topic) | **PUT** /bcf/2.1/projects/{projects_pk}/full-topic/{guid} | Update all fields of a topic
*BcfApi* | [**full_update_topic**](docs/BcfApi.md#full_update_topic) | **PUT** /bcf/2.1/projects/{projects_pk}/topics/{guid} | Update all fields of a topic
*BcfApi* | [**full_update_viewpoint**](docs/BcfApi.md#full_update_viewpoint) | **PUT** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid} | Update all fields of a Viewpoint
*BcfApi* | [**get_bcf_project**](docs/BcfApi.md#get_bcf_project) | **GET** /bcf/2.1/projects/{id} | Retrieve a BCF project
*BcfApi* | [**get_bcf_projects**](docs/BcfApi.md#get_bcf_projects) | **GET** /bcf/2.1/projects | Retrieve all BCF projects
*BcfApi* | [**get_colorings**](docs/BcfApi.md#get_colorings) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid}/coloring | Retrieve all colorings of a viewpoint
*BcfApi* | [**get_comment**](docs/BcfApi.md#get_comment) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments/{guid} | Retrieve a comment
*BcfApi* | [**get_comments**](docs/BcfApi.md#get_comments) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments | Retrieve all comments
*BcfApi* | [**get_detailed_extensions**](docs/BcfApi.md#get_detailed_extensions) | **GET** /bcf/2.1/projects/{id}/detailed-extensions | Retrieve project detailed extensions
*BcfApi* | [**get_extensions**](docs/BcfApi.md#get_extensions) | **GET** /bcf/2.1/projects/{id}/extensions | Retrieve project extensions
*BcfApi* | [**get_full_topic**](docs/BcfApi.md#get_full_topic) | **GET** /bcf/2.1/projects/{projects_pk}/full-topic/{guid} | Retrieve a full topic
*BcfApi* | [**get_full_topics**](docs/BcfApi.md#get_full_topics) | **GET** /bcf/2.1/projects/{projects_pk}/full-topic | Retrieve all full topics
*BcfApi* | [**get_selections**](docs/BcfApi.md#get_selections) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid}/selection | Retrieve all selections of a viewpoint
*BcfApi* | [**get_snapshot**](docs/BcfApi.md#get_snapshot) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid}/snapshot | Retrieve the viewpoint&#39; snapshot
*BcfApi* | [**get_topic**](docs/BcfApi.md#get_topic) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{guid} | Retrieve a topic
*BcfApi* | [**get_topic_viewpoints**](docs/BcfApi.md#get_topic_viewpoints) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/topic-viewpoints | Retrieve all viewpoints attached to the topic
*BcfApi* | [**get_topics**](docs/BcfApi.md#get_topics) | **GET** /bcf/2.1/projects/{projects_pk}/topics | Retrieve all topics
*BcfApi* | [**get_user**](docs/BcfApi.md#get_user) | **GET** /bcf/2.1/current-user | Get current user info
*BcfApi* | [**get_viewpoint**](docs/BcfApi.md#get_viewpoint) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid} | Retrieve a Viewpoint
*BcfApi* | [**get_viewpoints**](docs/BcfApi.md#get_viewpoints) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints | Retrieve all Viewpoints of a topic
*BcfApi* | [**get_visibilities**](docs/BcfApi.md#get_visibilities) | **GET** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid}/visibility | Retrieve all visibilities of a viewpoint
*BcfApi* | [**import_bcf**](docs/BcfApi.md#import_bcf) | **POST** /bcf/2.1/projects/{id}/import | Import bcf-xml format into this project
*BcfApi* | [**update_bcf_project**](docs/BcfApi.md#update_bcf_project) | **PATCH** /bcf/2.1/projects/{id} | Update some fields of a BCF project
*BcfApi* | [**update_comment**](docs/BcfApi.md#update_comment) | **PATCH** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/comments/{guid} | Update some fields of a comment
*BcfApi* | [**update_extension_label**](docs/BcfApi.md#update_extension_label) | **PATCH** /bcf/2.1/projects/{projects_pk}/extension/label/{id} | Update a Label
*BcfApi* | [**update_extension_priority**](docs/BcfApi.md#update_extension_priority) | **PATCH** /bcf/2.1/projects/{projects_pk}/extension/priority/{id} | Update a Priority
*BcfApi* | [**update_extension_stage**](docs/BcfApi.md#update_extension_stage) | **PATCH** /bcf/2.1/projects/{projects_pk}/extension/stage/{id} | Update a Stage
*BcfApi* | [**update_extension_status**](docs/BcfApi.md#update_extension_status) | **PATCH** /bcf/2.1/projects/{projects_pk}/extension/status/{id} | Update a TopicStatus
*BcfApi* | [**update_extension_type**](docs/BcfApi.md#update_extension_type) | **PATCH** /bcf/2.1/projects/{projects_pk}/extension/type/{id} | Update a TopicType
*BcfApi* | [**update_full_topic**](docs/BcfApi.md#update_full_topic) | **PATCH** /bcf/2.1/projects/{projects_pk}/full-topic/{guid} | Update some fields of a topic
*BcfApi* | [**update_topic**](docs/BcfApi.md#update_topic) | **PATCH** /bcf/2.1/projects/{projects_pk}/topics/{guid} | Update some fields of a topic
*BcfApi* | [**update_viewpoint**](docs/BcfApi.md#update_viewpoint) | **PATCH** /bcf/2.1/projects/{projects_pk}/topics/{topics_guid}/viewpoints/{guid} | Update some fields of a Viewpoint
*CheckerApi* | [**create_checker**](docs/CheckerApi.md#create_checker) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker | Create a checker to a model
*CheckerApi* | [**create_checker_result**](docs/CheckerApi.md#create_checker_result) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{checker_pk}/result | Create a CheckerResult
*CheckerApi* | [**create_checkplan**](docs/CheckerApi.md#create_checkplan) | **POST** /cloud/{cloud_pk}/project/{project_pk}/checkplan | Create a Checkplan
*CheckerApi* | [**create_rule**](docs/CheckerApi.md#create_rule) | **POST** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule | Create a Rule
*CheckerApi* | [**create_rule_component**](docs/CheckerApi.md#create_rule_component) | **POST** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{rule_pk}/rulecomponent | Create a RuleComponent
*CheckerApi* | [**create_ruleset**](docs/CheckerApi.md#create_ruleset) | **POST** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset | Create a Ruleset
*CheckerApi* | [**delete_checker**](docs/CheckerApi.md#delete_checker) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{id} | Delete a checker of a model
*CheckerApi* | [**delete_checker_result**](docs/CheckerApi.md#delete_checker_result) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{checker_pk}/result/{id} | Delete a CheckerResult
*CheckerApi* | [**delete_checkplan**](docs/CheckerApi.md#delete_checkplan) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{id} | Delete a Checkplan
*CheckerApi* | [**delete_rule**](docs/CheckerApi.md#delete_rule) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{id} | Delete a Rule
*CheckerApi* | [**delete_rule_component**](docs/CheckerApi.md#delete_rule_component) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{rule_pk}/rulecomponent/{id} | Delete a RuleComponent
*CheckerApi* | [**delete_ruleset**](docs/CheckerApi.md#delete_ruleset) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{id} | Delete a Ruleset
*CheckerApi* | [**get_checker**](docs/CheckerApi.md#get_checker) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{id} | Retrieve a checker of a model
*CheckerApi* | [**get_checker_result**](docs/CheckerApi.md#get_checker_result) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{checker_pk}/result/{id} | Retrieve one CheckerResult
*CheckerApi* | [**get_checker_results**](docs/CheckerApi.md#get_checker_results) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{checker_pk}/result | Retrieve all CheckerResults
*CheckerApi* | [**get_checkers**](docs/CheckerApi.md#get_checkers) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker | Retrieve all checkers of a model
*CheckerApi* | [**get_checkplan**](docs/CheckerApi.md#get_checkplan) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{id} | Retrieve one Checkplan
*CheckerApi* | [**get_checkplans**](docs/CheckerApi.md#get_checkplans) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan | Retrieve all Checkplans
*CheckerApi* | [**get_rule**](docs/CheckerApi.md#get_rule) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{id} | Retrieve one Rule
*CheckerApi* | [**get_rule_component**](docs/CheckerApi.md#get_rule_component) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{rule_pk}/rulecomponent/{id} | Retrieve one RuleComponent
*CheckerApi* | [**get_rule_components**](docs/CheckerApi.md#get_rule_components) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{rule_pk}/rulecomponent | Retrieve all RuleComponents
*CheckerApi* | [**get_rules**](docs/CheckerApi.md#get_rules) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule | Retrieve all Rules
*CheckerApi* | [**get_ruleset**](docs/CheckerApi.md#get_ruleset) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{id} | Retrieve one Ruleset
*CheckerApi* | [**get_rulesets**](docs/CheckerApi.md#get_rulesets) | **GET** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset | Retrieve all Rulesets
*CheckerApi* | [**launch_new_check**](docs/CheckerApi.md#launch_new_check) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{id}/launch-check | Launch a new check on the model
*CheckerApi* | [**update_checker**](docs/CheckerApi.md#update_checker) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{id} | Update some fields of a checker of a model
*CheckerApi* | [**update_checker_result**](docs/CheckerApi.md#update_checker_result) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/checker/{checker_pk}/result/{id} | Update some fields of a CheckerResult
*CheckerApi* | [**update_checkplan**](docs/CheckerApi.md#update_checkplan) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{id} | Update some fields of a Checkplan
*CheckerApi* | [**update_rule**](docs/CheckerApi.md#update_rule) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{id} | Update some fields of a Rule
*CheckerApi* | [**update_rule_component**](docs/CheckerApi.md#update_rule_component) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{ruleset_pk}/rule/{rule_pk}/rulecomponent/{id} | Update some fields of a RuleComponent
*CheckerApi* | [**update_ruleset**](docs/CheckerApi.md#update_ruleset) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/checkplan/{check_plan_pk}/ruleset/{id} | Update some fields of a Ruleset
*CollaborationApi* | [**accept_user_invitation**](docs/CollaborationApi.md#accept_user_invitation) | **POST** /user/invitations/{id}/accept | Accept an invitation
*CollaborationApi* | [**accept_validation**](docs/CollaborationApi.md#accept_validation) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id}/accept | Accept a validation
*CollaborationApi* | [**add_document_tag**](docs/CollaborationApi.md#add_document_tag) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/tag | Add a tag to a document
*CollaborationApi* | [**add_group_member**](docs/CollaborationApi.md#add_group_member) | **POST** /cloud/{cloud_pk}/project/{project_pk}/group/{group_pk}/member | Add a user to a group
*CollaborationApi* | [**cancel_cloud_user_invitation**](docs/CollaborationApi.md#cancel_cloud_user_invitation) | **DELETE** /cloud/{cloud_pk}/invitation/{id} | Cancel a pending invitation
*CollaborationApi* | [**cancel_project_user_invitation**](docs/CollaborationApi.md#cancel_project_user_invitation) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/invitation/{id} | Cancel a pending invitation
*CollaborationApi* | [**check_access**](docs/CollaborationApi.md#check_access) | **GET** /cloud/{id}/check-access | Check app access from cloud
*CollaborationApi* | [**close_visa**](docs/CollaborationApi.md#close_visa) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id}/close | Close a visa of a document
*CollaborationApi* | [**create_classification**](docs/CollaborationApi.md#create_classification) | **POST** /cloud/{cloud_pk}/project/{project_pk}/classification | Create a classification
*CollaborationApi* | [**create_cloud**](docs/CollaborationApi.md#create_cloud) | **POST** /cloud | Create a cloud
*CollaborationApi* | [**create_demo**](docs/CollaborationApi.md#create_demo) | **POST** /cloud/{id}/create-demo | Create a Demo project in a cloud
*CollaborationApi* | [**create_dms_tree**](docs/CollaborationApi.md#create_dms_tree) | **POST** /cloud/{cloud_pk}/project/{id}/dms-tree | Create a complete DMS tree
*CollaborationApi* | [**create_document**](docs/CollaborationApi.md#create_document) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document | Create a document
*CollaborationApi* | [**create_folder**](docs/CollaborationApi.md#create_folder) | **POST** /cloud/{cloud_pk}/project/{project_pk}/folder | Create a folder
*CollaborationApi* | [**create_manage_group**](docs/CollaborationApi.md#create_manage_group) | **POST** /cloud/{cloud_pk}/project/{project_pk}/group | Create a group
*CollaborationApi* | [**create_project**](docs/CollaborationApi.md#create_project) | **POST** /cloud/{cloud_pk}/project | Create a project
*CollaborationApi* | [**create_project_access_token**](docs/CollaborationApi.md#create_project_access_token) | **POST** /cloud/{cloud_pk}/project/{project_pk}/access-token | Create a token for this project
*CollaborationApi* | [**create_tag**](docs/CollaborationApi.md#create_tag) | **POST** /cloud/{cloud_pk}/project/{project_pk}/tag | Create a tag
*CollaborationApi* | [**create_validation**](docs/CollaborationApi.md#create_validation) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation | Add a validation to a visa
*CollaborationApi* | [**create_visa**](docs/CollaborationApi.md#create_visa) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa | Create a visa
*CollaborationApi* | [**create_visa_comment**](docs/CollaborationApi.md#create_visa_comment) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/comment | Add a comment
*CollaborationApi* | [**delete_all_document_history**](docs/CollaborationApi.md#delete_all_document_history) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/history/delete | Delete all document history
*CollaborationApi* | [**delete_classification**](docs/CollaborationApi.md#delete_classification) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/classification/{id} | Delete a classification
*CollaborationApi* | [**delete_cloud**](docs/CollaborationApi.md#delete_cloud) | **DELETE** /cloud/{id} | Delete a cloud
*CollaborationApi* | [**delete_cloud_user**](docs/CollaborationApi.md#delete_cloud_user) | **DELETE** /cloud/{cloud_pk}/user/{id} | Remove a user from a cloud
*CollaborationApi* | [**delete_document**](docs/CollaborationApi.md#delete_document) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{id} | Delete the document
*CollaborationApi* | [**delete_document_tag**](docs/CollaborationApi.md#delete_document_tag) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/tag/{id} | Delete a tag from a document
*CollaborationApi* | [**delete_folder**](docs/CollaborationApi.md#delete_folder) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/folder/{id} | Delete a folder
*CollaborationApi* | [**delete_group_member**](docs/CollaborationApi.md#delete_group_member) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/group/{group_pk}/member/{id} | Delete a user from a group
*CollaborationApi* | [**delete_manage_group**](docs/CollaborationApi.md#delete_manage_group) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/group/{id} | Delete a group
*CollaborationApi* | [**delete_project**](docs/CollaborationApi.md#delete_project) | **DELETE** /cloud/{cloud_pk}/project/{id} | Delete a project
*CollaborationApi* | [**delete_project_access_token**](docs/CollaborationApi.md#delete_project_access_token) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/access-token/{token} | Delete a token
*CollaborationApi* | [**delete_project_user**](docs/CollaborationApi.md#delete_project_user) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/user/{id} | Remove a user from a project
*CollaborationApi* | [**delete_tag**](docs/CollaborationApi.md#delete_tag) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/tag/{id} | Delete the tag
*CollaborationApi* | [**delete_validation**](docs/CollaborationApi.md#delete_validation) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id} | Remove a validation
*CollaborationApi* | [**delete_visa**](docs/CollaborationApi.md#delete_visa) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id} | Remove a visa
*CollaborationApi* | [**delete_visa_comment**](docs/CollaborationApi.md#delete_visa_comment) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/comment/{id} | Remove a comment
*CollaborationApi* | [**deny_user_invitation**](docs/CollaborationApi.md#deny_user_invitation) | **POST** /user/invitations/{id}/deny | Deny an invitation
*CollaborationApi* | [**deny_validation**](docs/CollaborationApi.md#deny_validation) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id}/deny | Deny a validation
*CollaborationApi* | [**get_classification**](docs/CollaborationApi.md#get_classification) | **GET** /cloud/{cloud_pk}/project/{project_pk}/classification/{id} | Retrieve a classification
*CollaborationApi* | [**get_classifications**](docs/CollaborationApi.md#get_classifications) | **GET** /cloud/{cloud_pk}/project/{project_pk}/classification | Retrieve all classifications
*CollaborationApi* | [**get_cloud**](docs/CollaborationApi.md#get_cloud) | **GET** /cloud/{id} | Retrieve one cloud
*CollaborationApi* | [**get_cloud_invitations**](docs/CollaborationApi.md#get_cloud_invitations) | **GET** /cloud/{cloud_pk}/invitation | Retrieve all pending invitations in the cloud
*CollaborationApi* | [**get_cloud_size**](docs/CollaborationApi.md#get_cloud_size) | **GET** /cloud/{id}/size | Get size of the cloud
*CollaborationApi* | [**get_cloud_user**](docs/CollaborationApi.md#get_cloud_user) | **GET** /cloud/{cloud_pk}/user/{id} | Retrieve a user in a cloud
*CollaborationApi* | [**get_cloud_users**](docs/CollaborationApi.md#get_cloud_users) | **GET** /cloud/{cloud_pk}/user | Retrieve all users in a cloud, or a list with a filter by email
*CollaborationApi* | [**get_clouds**](docs/CollaborationApi.md#get_clouds) | **GET** /cloud | Retrieve all clouds
*CollaborationApi* | [**get_document**](docs/CollaborationApi.md#get_document) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{id} | Retrieve a document
*CollaborationApi* | [**get_document_histories**](docs/CollaborationApi.md#get_document_histories) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/history | Retrieve all document histories
*CollaborationApi* | [**get_documents**](docs/CollaborationApi.md#get_documents) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document | Retrieve all documents
*CollaborationApi* | [**get_folder**](docs/CollaborationApi.md#get_folder) | **GET** /cloud/{cloud_pk}/project/{project_pk}/folder/{id} | Retrieve a folder
*CollaborationApi* | [**get_folder_project_users**](docs/CollaborationApi.md#get_folder_project_users) | **GET** /cloud/{cloud_pk}/project/{project_pk}/folder/{folder_pk}/user | Retrieve all users in a project with the permission on the folder
*CollaborationApi* | [**get_folders**](docs/CollaborationApi.md#get_folders) | **GET** /cloud/{cloud_pk}/project/{project_pk}/folder | Retrieve all folders
*CollaborationApi* | [**get_group**](docs/CollaborationApi.md#get_group) | **GET** /cloud/{cloud_pk}/project/{project_pk}/me/group/{id} | Retrieve a group
*CollaborationApi* | [**get_groups**](docs/CollaborationApi.md#get_groups) | **GET** /cloud/{cloud_pk}/project/{project_pk}/me/group | Retrieve all groups
*CollaborationApi* | [**get_manage_group**](docs/CollaborationApi.md#get_manage_group) | **GET** /cloud/{cloud_pk}/project/{project_pk}/group/{id} | Retrieve a group
*CollaborationApi* | [**get_manage_groups**](docs/CollaborationApi.md#get_manage_groups) | **GET** /cloud/{cloud_pk}/project/{project_pk}/group | Retrieve all groups
*CollaborationApi* | [**get_project**](docs/CollaborationApi.md#get_project) | **GET** /cloud/{cloud_pk}/project/{id} | Retrieve a project
*CollaborationApi* | [**get_project_access_token**](docs/CollaborationApi.md#get_project_access_token) | **GET** /cloud/{cloud_pk}/project/{project_pk}/access-token/{token} | Retrieve one token created for this project
*CollaborationApi* | [**get_project_access_tokens**](docs/CollaborationApi.md#get_project_access_tokens) | **GET** /cloud/{cloud_pk}/project/{project_pk}/access-token | Retrieve all tokens created for this project
*CollaborationApi* | [**get_project_creator_visas**](docs/CollaborationApi.md#get_project_creator_visas) | **GET** /cloud/{cloud_pk}/project/{project_pk}/me/visa/creator | List visas created by user
*CollaborationApi* | [**get_project_dms_tree**](docs/CollaborationApi.md#get_project_dms_tree) | **GET** /cloud/{cloud_pk}/project/{id}/dms-tree | Retrieve the complete DMS tree
*CollaborationApi* | [**get_project_folder_tree_serializers**](docs/CollaborationApi.md#get_project_folder_tree_serializers) | **GET** /cloud/{cloud_pk}/project/folder-trees | Retrieve folder tree for all projects
*CollaborationApi* | [**get_project_invitations**](docs/CollaborationApi.md#get_project_invitations) | **GET** /cloud/{cloud_pk}/project/{project_pk}/invitation | Retrieve all pending invitations in the project
*CollaborationApi* | [**get_project_size**](docs/CollaborationApi.md#get_project_size) | **GET** /cloud/{cloud_pk}/project/{id}/size | Get size of all model files in the project
*CollaborationApi* | [**get_project_sub_tree**](docs/CollaborationApi.md#get_project_sub_tree) | **GET** /cloud/{cloud_pk}/project/subtree | Retrieve the complete projects tree of the cloud
*CollaborationApi* | [**get_project_tree**](docs/CollaborationApi.md#get_project_tree) | **GET** /cloud/{cloud_pk}/project/{id}/tree | Retrieve the complete DMS tree
*CollaborationApi* | [**get_project_users**](docs/CollaborationApi.md#get_project_users) | **GET** /cloud/{cloud_pk}/project/{project_pk}/user | Retrieve all users in a project, or a list with a filter by email
*CollaborationApi* | [**get_project_validator_visas**](docs/CollaborationApi.md#get_project_validator_visas) | **GET** /cloud/{cloud_pk}/project/{project_pk}/me/visa/validator | List visas where user is a validator
*CollaborationApi* | [**get_projects**](docs/CollaborationApi.md#get_projects) | **GET** /cloud/{cloud_pk}/project | Retrieve all projects
*CollaborationApi* | [**get_self_projects**](docs/CollaborationApi.md#get_self_projects) | **GET** /user/projects | List current user&#39;s projects
*CollaborationApi* | [**get_self_user**](docs/CollaborationApi.md#get_self_user) | **GET** /user | Get info about the current user
*CollaborationApi* | [**get_tag**](docs/CollaborationApi.md#get_tag) | **GET** /cloud/{cloud_pk}/project/{project_pk}/tag/{id} | Retrieve a tag
*CollaborationApi* | [**get_tags**](docs/CollaborationApi.md#get_tags) | **GET** /cloud/{cloud_pk}/project/{project_pk}/tag | Retrieve all tags
*CollaborationApi* | [**get_user_invitation**](docs/CollaborationApi.md#get_user_invitation) | **GET** /user/invitations/{id} | Retrieve an invitation
*CollaborationApi* | [**get_user_invitations**](docs/CollaborationApi.md#get_user_invitations) | **GET** /user/invitations | List user&#39;s invitations
*CollaborationApi* | [**get_validation**](docs/CollaborationApi.md#get_validation) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id} | Retrieve a validation to a visa
*CollaborationApi* | [**get_validations**](docs/CollaborationApi.md#get_validations) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation | List all validations to a visa
*CollaborationApi* | [**get_visa**](docs/CollaborationApi.md#get_visa) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id} | Retrieve a visa of a document
*CollaborationApi* | [**get_visa_comment**](docs/CollaborationApi.md#get_visa_comment) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/comment/{id} | Retrieve a comment
*CollaborationApi* | [**get_visa_comments**](docs/CollaborationApi.md#get_visa_comments) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/comment | List all comment of a visa
*CollaborationApi* | [**get_visas**](docs/CollaborationApi.md#get_visas) | **GET** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa | List all visas of a document
*CollaborationApi* | [**invite_cloud_user**](docs/CollaborationApi.md#invite_cloud_user) | **POST** /cloud/{cloud_pk}/invitation | Invite a cloud administrator
*CollaborationApi* | [**invite_project_user**](docs/CollaborationApi.md#invite_project_user) | **POST** /cloud/{cloud_pk}/project/{project_pk}/invitation | Invite a project member
*CollaborationApi* | [**leave_project**](docs/CollaborationApi.md#leave_project) | **POST** /cloud/{cloud_pk}/project/{id}/leave | Leave the project
*CollaborationApi* | [**leave_version_document_history**](docs/CollaborationApi.md#leave_version_document_history) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/history/{id}/leave | Leave the history version
*CollaborationApi* | [**make_head_version_document_history**](docs/CollaborationApi.md#make_head_version_document_history) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/history/{id}/head-version | Make the head of the version
*CollaborationApi* | [**pause_visa**](docs/CollaborationApi.md#pause_visa) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id}/pause | Pause a visa of a document
*CollaborationApi* | [**reset_validation**](docs/CollaborationApi.md#reset_validation) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id}/reset | Reset a validation
*CollaborationApi* | [**resume_visa**](docs/CollaborationApi.md#resume_visa) | **POST** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id}/resume | Resume a visa of a document
*CollaborationApi* | [**update_classification**](docs/CollaborationApi.md#update_classification) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/classification/{id} | Update some fields of a classification
*CollaborationApi* | [**update_cloud**](docs/CollaborationApi.md#update_cloud) | **PATCH** /cloud/{id} | Update some fields of a cloud
*CollaborationApi* | [**update_cloud_user**](docs/CollaborationApi.md#update_cloud_user) | **PATCH** /cloud/{cloud_pk}/user/{id} | Change the user role in the cloud
*CollaborationApi* | [**update_document**](docs/CollaborationApi.md#update_document) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/document/{id} | Update some fields of the document
*CollaborationApi* | [**update_folder**](docs/CollaborationApi.md#update_folder) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/folder/{id} | Update some fields of a folder
*CollaborationApi* | [**update_group_folder**](docs/CollaborationApi.md#update_group_folder) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/folder/{folder_pk}/group/{id} | Update the permission of a group on a folder
*CollaborationApi* | [**update_manage_group**](docs/CollaborationApi.md#update_manage_group) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/group/{id} | Update some fields of a group
*CollaborationApi* | [**update_project**](docs/CollaborationApi.md#update_project) | **PATCH** /cloud/{cloud_pk}/project/{id} | Update some fields of a project
*CollaborationApi* | [**update_project_access_token**](docs/CollaborationApi.md#update_project_access_token) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/access-token/{token} | Update some fields of a token
*CollaborationApi* | [**update_project_user**](docs/CollaborationApi.md#update_project_user) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/user/{id} | Change the user role in the cloud
*CollaborationApi* | [**update_tag**](docs/CollaborationApi.md#update_tag) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/tag/{id} | Update some fields of the tag
*CollaborationApi* | [**update_validation**](docs/CollaborationApi.md#update_validation) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/validation/{id} | Update the validator of validation
*CollaborationApi* | [**update_visa**](docs/CollaborationApi.md#update_visa) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{id} | Update some fields of a visa
*CollaborationApi* | [**update_visa_comment**](docs/CollaborationApi.md#update_visa_comment) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/document/{document_pk}/visa/{visa_pk}/comment/{id} | Update some fields of a comment
*IfcApi* | [**add_ifc_errors_deprecated**](docs/IfcApi.md#add_ifc_errors_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/errors | Add errors to model
*IfcApi* | [**bulk_delete_ifc_classifications_deprecated**](docs/IfcApi.md#bulk_delete_ifc_classifications_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification/list_destroy | Remove all classifications from model&#39;s elements
*IfcApi* | [**bulk_delete_ifc_properties_deprecated**](docs/IfcApi.md#bulk_delete_ifc_properties_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/bulk_destroy | Delete many Property of a model
*IfcApi* | [**bulk_delete_ifc_property_definitions_deprecated**](docs/IfcApi.md#bulk_delete_ifc_property_definitions_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition/bulk_destroy | Delete many PropertyDefinitions of a model
*IfcApi* | [**bulk_delete_ifc_units_deprecated**](docs/IfcApi.md#bulk_delete_ifc_units_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit/bulk_destroy | Delete many Units of a model
*IfcApi* | [**bulk_delete_property_set_deprecated**](docs/IfcApi.md#bulk_delete_property_set_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset/bulk_destroy | Delete many PropertySet of a model
*IfcApi* | [**bulk_full_update_elements_deprecated**](docs/IfcApi.md#bulk_full_update_elements_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/bulk_update | Update many elements at once (only changing fields may be defined)
*IfcApi* | [**bulk_full_update_ifc_property_deprecated**](docs/IfcApi.md#bulk_full_update_ifc_property_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/bulk_update | Update some fields of many properties of a model
*IfcApi* | [**bulk_remove_classifications_of_element_deprecated**](docs/IfcApi.md#bulk_remove_classifications_of_element_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/classification/bulk_destroy | Remove many classifications from an element
*IfcApi* | [**bulk_remove_documents_of_element_deprecated**](docs/IfcApi.md#bulk_remove_documents_of_element_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/documents/bulk_destroy | Remove many documents from an element
*IfcApi* | [**bulk_remove_elements_from_classification_deprecated**](docs/IfcApi.md#bulk_remove_elements_from_classification_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification/{model_classification_pk}/element/bulk_destroy | Remove the classifications from all elements
*IfcApi* | [**bulk_update_elements_deprecated**](docs/IfcApi.md#bulk_update_elements_deprecated) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/bulk_update | Update many elements at once (all field must be defined)
*IfcApi* | [**bulk_update_ifc_property_deprecated**](docs/IfcApi.md#bulk_update_ifc_property_deprecated) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/bulk_update | Update all fields of many properties of a model
*IfcApi* | [**create_access_token_deprecated**](docs/IfcApi.md#create_access_token_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/access_token | Create a token for this model
*IfcApi* | [**create_building_deprecated**](docs/IfcApi.md#create_building_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building | Create a building of a model
*IfcApi* | [**create_building_plan_deprecated**](docs/IfcApi.md#create_building_plan_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{building_uuid}/plan/add | Create a relation between a 2d model and a building
*IfcApi* | [**create_checker_deprecated**](docs/IfcApi.md#create_checker_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker | Create a checker to a model
*IfcApi* | [**create_checker_result_deprecated**](docs/IfcApi.md#create_checker_result_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{checker_pk}/result | Create a CheckerResult
*IfcApi* | [**create_classification_element_relations_deprecated**](docs/IfcApi.md#create_classification_element_relations_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification-element | Create association between existing classification and existing element
*IfcApi* | [**create_classifications_of_element_deprecated**](docs/IfcApi.md#create_classifications_of_element_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/classification | Create one or many classifications to an element
*IfcApi* | [**create_element_deprecated**](docs/IfcApi.md#create_element_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element | Create an element in the model
*IfcApi* | [**create_element_property_set_deprecated**](docs/IfcApi.md#create_element_property_set_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset | Create a PropertySets to an element
*IfcApi* | [**create_element_property_set_property_definition_deprecated**](docs/IfcApi.md#create_element_property_set_property_definition_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition | Create a Definition to a Property
*IfcApi* | [**create_element_property_set_property_definition_unit_deprecated**](docs/IfcApi.md#create_element_property_set_property_definition_unit_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit | Create a Unit to a Definition
*IfcApi* | [**create_element_property_set_property_deprecated**](docs/IfcApi.md#create_element_property_set_property_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property | Create a property to a PropertySet
*IfcApi* | [**create_ifc_deprecated**](docs/IfcApi.md#create_ifc_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/create-model | Make a PDF or Image file a Model
*IfcApi* | [**create_ifc_property_definition_deprecated**](docs/IfcApi.md#create_ifc_property_definition_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition | Create a PropertyDefinition on the model
*IfcApi* | [**create_ifc_unit_deprecated**](docs/IfcApi.md#create_ifc_unit_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit | Create a Unit on a model
*IfcApi* | [**create_layer_deprecated**](docs/IfcApi.md#create_layer_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/layer | Create a layer in the model
*IfcApi* | [**create_meta_building_deprecated**](docs/IfcApi.md#create_meta_building_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/create-metabuilding | Create an empty 3D Model
*IfcApi* | [**create_property_set_deprecated**](docs/IfcApi.md#create_property_set_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset | Create one or many PropertySet
*IfcApi* | [**create_property_set_element_relations_deprecated**](docs/IfcApi.md#create_property_set_element_relations_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset-element | Create association between PropertySet and element
*IfcApi* | [**create_raw_elements_deprecated**](docs/IfcApi.md#create_raw_elements_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/raw | Create elements in an optimized format
*IfcApi* | [**create_space_deprecated**](docs/IfcApi.md#create_space_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/space | Create a space in the model
*IfcApi* | [**create_storey_deprecated**](docs/IfcApi.md#create_storey_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey | Create a storey of a model
*IfcApi* | [**create_storey_plan_deprecated**](docs/IfcApi.md#create_storey_plan_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{storey_uuid}/plan/add | Create a relation between a 2d model and a storey
*IfcApi* | [**create_system_deprecated**](docs/IfcApi.md#create_system_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/system | Create a system in the model
*IfcApi* | [**create_tileset_deprecated**](docs/IfcApi.md#create_tileset_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/tileset | Create the tileset of the model and upload all files
*IfcApi* | [**create_zone_deprecated**](docs/IfcApi.md#create_zone_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone | Create a zone in the model
*IfcApi* | [**create_zone_space_deprecated**](docs/IfcApi.md#create_zone_space_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{zone_pk}/space | Create a space in a zone
*IfcApi* | [**delete_access_token_deprecated**](docs/IfcApi.md#delete_access_token_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/access_token/{token} | Delete a token
*IfcApi* | [**delete_building_deprecated**](docs/IfcApi.md#delete_building_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{uuid} | Delete a building of a model
*IfcApi* | [**delete_building_plan_deprecated**](docs/IfcApi.md#delete_building_plan_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{building_uuid}/plan/{id} | Delete the relation between a 2d model and a building
*IfcApi* | [**delete_checker_deprecated**](docs/IfcApi.md#delete_checker_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{id} | Delete a checker of a model
*IfcApi* | [**delete_checker_result_deprecated**](docs/IfcApi.md#delete_checker_result_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{checker_pk}/result/{id} | Delete a CheckerResult
*IfcApi* | [**delete_element_deprecated**](docs/IfcApi.md#delete_element_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{uuid} | Delete an element of a model
*IfcApi* | [**delete_ifc_deprecated**](docs/IfcApi.md#delete_ifc_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id} | Delete a model
*IfcApi* | [**delete_ifc_property_definition_deprecated**](docs/IfcApi.md#delete_ifc_property_definition_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition/{id} | Delete a PropertyDefinitions of a model
*IfcApi* | [**delete_ifc_property_deprecated**](docs/IfcApi.md#delete_ifc_property_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/{id} | Delete a Property of a model
*IfcApi* | [**delete_ifc_unit_deprecated**](docs/IfcApi.md#delete_ifc_unit_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit/{id} | Delete a Unit of a model
*IfcApi* | [**delete_ifc_without_doc_deprecated**](docs/IfcApi.md#delete_ifc_without_doc_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/delete-model | Delete the Model without deleting the related document
*IfcApi* | [**delete_layer_deprecated**](docs/IfcApi.md#delete_layer_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/layer/{id} | Delete a layer of a model
*IfcApi* | [**delete_property_set_deprecated**](docs/IfcApi.md#delete_property_set_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset/{id} | Delete a PropertySet of a model
*IfcApi* | [**delete_space_deprecated**](docs/IfcApi.md#delete_space_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/space/{id} | Delete a space
*IfcApi* | [**delete_storey_deprecated**](docs/IfcApi.md#delete_storey_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{uuid} | Delete a storey of a model
*IfcApi* | [**delete_storey_plan_deprecated**](docs/IfcApi.md#delete_storey_plan_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{storey_uuid}/plan/{id} | Delete the relation between a 2d model and a storey
*IfcApi* | [**delete_system_deprecated**](docs/IfcApi.md#delete_system_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/system/{uuid} | Delete a system of a model
*IfcApi* | [**delete_zone_deprecated**](docs/IfcApi.md#delete_zone_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{id} | Delete a zone of a model
*IfcApi* | [**delete_zone_space_deprecated**](docs/IfcApi.md#delete_zone_space_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{zone_pk}/space/{id} | Delete a space of a zone
*IfcApi* | [**export_ifc_deprecated**](docs/IfcApi.md#export_ifc_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/export | Export IFC
*IfcApi* | [**full_update_element_deprecated**](docs/IfcApi.md#full_update_element_deprecated) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{uuid} | Update all fields of an element
*IfcApi* | [**get_access_token_deprecated**](docs/IfcApi.md#get_access_token_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/access_token/{token} | Retrieve one token created for this model
*IfcApi* | [**get_access_tokens_deprecated**](docs/IfcApi.md#get_access_tokens_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/access_token | Retrieve all tokens created for this model
*IfcApi* | [**get_building_deprecated**](docs/IfcApi.md#get_building_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{uuid} | Retrieve a building of a model
*IfcApi* | [**get_building_plan_positioning_deprecated**](docs/IfcApi.md#get_building_plan_positioning_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{building_uuid}/plan/{id}/positioning | Retrieve the postioning of the plan in the building
*IfcApi* | [**get_buildings_deprecated**](docs/IfcApi.md#get_buildings_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building | Retrieve all buildings of a model
*IfcApi* | [**get_checker_deprecated**](docs/IfcApi.md#get_checker_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{id} | Retrieve a checker of a model
*IfcApi* | [**get_checker_result_deprecated**](docs/IfcApi.md#get_checker_result_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{checker_pk}/result/{id} | Retrieve one CheckerResult
*IfcApi* | [**get_checker_results_deprecated**](docs/IfcApi.md#get_checker_results_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{checker_pk}/result | Retrieve all CheckerResults
*IfcApi* | [**get_checkers_deprecated**](docs/IfcApi.md#get_checkers_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker | Retrieve all checkers of a model
*IfcApi* | [**get_classifications_of_element_deprecated**](docs/IfcApi.md#get_classifications_of_element_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/classification | Retrieve all classifications of an element
*IfcApi* | [**get_documents_of_element_deprecated**](docs/IfcApi.md#get_documents_of_element_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/documents | Retrieve all documents of an element
*IfcApi* | [**get_element_deprecated**](docs/IfcApi.md#get_element_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{uuid} | Retrieve an element of a model
*IfcApi* | [**get_element_linked_documents_deprecated**](docs/IfcApi.md#get_element_linked_documents_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/documents | Retrieve all documents linked to any element
*IfcApi* | [**get_element_property_set_deprecated**](docs/IfcApi.md#get_element_property_set_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{id} | Retrieve a PropertySet of an element
*IfcApi* | [**get_element_property_set_properties_deprecated**](docs/IfcApi.md#get_element_property_set_properties_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property | Retrieve all Properties of a PropertySet
*IfcApi* | [**get_element_property_set_property_definition_deprecated**](docs/IfcApi.md#get_element_property_set_property_definition_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{id} | Retrieve a Definition of a Property
*IfcApi* | [**get_element_property_set_property_definition_unit_deprecated**](docs/IfcApi.md#get_element_property_set_property_definition_unit_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit/{id} | Retrieve a Unit of a Definition
*IfcApi* | [**get_element_property_set_property_definition_units_deprecated**](docs/IfcApi.md#get_element_property_set_property_definition_units_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit | Retrieve all Units of a Definition
*IfcApi* | [**get_element_property_set_property_definitions_deprecated**](docs/IfcApi.md#get_element_property_set_property_definitions_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition | Retrieve all Definitions of a PropertySet
*IfcApi* | [**get_element_property_set_property_deprecated**](docs/IfcApi.md#get_element_property_set_property_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Retrieve a Property of a PropertySet
*IfcApi* | [**get_element_property_sets_deprecated**](docs/IfcApi.md#get_element_property_sets_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset | Retrieve all PropertySets of an element
*IfcApi* | [**get_elements_deprecated**](docs/IfcApi.md#get_elements_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element | Retrieve all elements of a model
*IfcApi* | [**get_elements_from_classification_deprecated**](docs/IfcApi.md#get_elements_from_classification_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification/{model_classification_pk}/element | Retrieve all elements with the classification
*IfcApi* | [**get_ifc_classifications_deprecated**](docs/IfcApi.md#get_ifc_classifications_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification | Retrieve all classifications in a model
*IfcApi* | [**get_ifc_deprecated**](docs/IfcApi.md#get_ifc_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id} | Retrieve one model
*IfcApi* | [**get_ifc_material_deprecated**](docs/IfcApi.md#get_ifc_material_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/material/{id} | Retrieve a material of a model
*IfcApi* | [**get_ifc_materials_deprecated**](docs/IfcApi.md#get_ifc_materials_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/material | Retrieve all materials of a model
*IfcApi* | [**get_ifc_properties_deprecated**](docs/IfcApi.md#get_ifc_properties_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property | Retrieve all Properties of a model
*IfcApi* | [**get_ifc_property_definition_deprecated**](docs/IfcApi.md#get_ifc_property_definition_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition/{id} | Retrieve a PropertyDefinition of a model
*IfcApi* | [**get_ifc_property_definitions_deprecated**](docs/IfcApi.md#get_ifc_property_definitions_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition | Retrieve all PropertyDefinitions of a model
*IfcApi* | [**get_ifc_property_deprecated**](docs/IfcApi.md#get_ifc_property_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/{id} | Retrieve a Property of a model
*IfcApi* | [**get_ifc_unit_deprecated**](docs/IfcApi.md#get_ifc_unit_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit/{id} | Retrieve a Unit of a model
*IfcApi* | [**get_ifc_units_deprecated**](docs/IfcApi.md#get_ifc_units_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit | Retrieve all Units of a model
*IfcApi* | [**get_ifcs_deprecated**](docs/IfcApi.md#get_ifcs_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc | Retrieve all models
*IfcApi* | [**get_layer_deprecated**](docs/IfcApi.md#get_layer_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/layer/{id} | Retrieve a layer of a model
*IfcApi* | [**get_layers_deprecated**](docs/IfcApi.md#get_layers_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/layer | Retrieve all layers of a model
*IfcApi* | [**get_material_deprecated**](docs/IfcApi.md#get_material_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/material/{id} | Retrieve a material of a model
*IfcApi* | [**get_materials_deprecated**](docs/IfcApi.md#get_materials_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/material | Retrieve all materials of a model
*IfcApi* | [**get_processor_handler_deprecated**](docs/IfcApi.md#get_processor_handler_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/processorhandler/{id} | Retrieve a processor handler
*IfcApi* | [**get_processor_handlers_deprecated**](docs/IfcApi.md#get_processor_handlers_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/processorhandler | Get all processor handlers
*IfcApi* | [**get_property_set_deprecated**](docs/IfcApi.md#get_property_set_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset/{id} | Retrieve a PropertySet of a model
*IfcApi* | [**get_property_sets_deprecated**](docs/IfcApi.md#get_property_sets_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset | Retrieve all PropertySets of a model
*IfcApi* | [**get_raw_elements_deprecated**](docs/IfcApi.md#get_raw_elements_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/raw | Retrieve all elements in a optimized format
*IfcApi* | [**get_simple_element_deprecated**](docs/IfcApi.md#get_simple_element_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{uuid}/simple | Retrieve an element of a model with a simple value representation
*IfcApi* | [**get_simple_elements_deprecated**](docs/IfcApi.md#get_simple_elements_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/simple | Retrieve all elements of a model with a simple value representation
*IfcApi* | [**get_space_deprecated**](docs/IfcApi.md#get_space_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/space/{id} | Retrieve one space of the model
*IfcApi* | [**get_spaces_deprecated**](docs/IfcApi.md#get_spaces_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/space | Retrieve all spaces of the model
*IfcApi* | [**get_storey_deprecated**](docs/IfcApi.md#get_storey_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{uuid} | Retrieve a storey of a model
*IfcApi* | [**get_storey_plan_positioning_deprecated**](docs/IfcApi.md#get_storey_plan_positioning_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{storey_uuid}/plan/{id}/positioning | Retrieve the postioning of the plan in the storey
*IfcApi* | [**get_storeys_deprecated**](docs/IfcApi.md#get_storeys_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey | Retrieve all storeys of a model
*IfcApi* | [**get_system_deprecated**](docs/IfcApi.md#get_system_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/system/{uuid} | Retrieve a system of a model
*IfcApi* | [**get_systems_deprecated**](docs/IfcApi.md#get_systems_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/system | Retrieve all systems of a model
*IfcApi* | [**get_tileset_deprecated**](docs/IfcApi.md#get_tileset_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/tileset | Retrieve the tileset of the model
*IfcApi* | [**get_zone_deprecated**](docs/IfcApi.md#get_zone_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{id} | Retrieve one zone of a model
*IfcApi* | [**get_zone_space_deprecated**](docs/IfcApi.md#get_zone_space_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{zone_pk}/space/{id} | Retrieve one space of a zone
*IfcApi* | [**get_zone_spaces_deprecated**](docs/IfcApi.md#get_zone_spaces_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{zone_pk}/space | Retrieve all spaces of a zone
*IfcApi* | [**get_zones_deprecated**](docs/IfcApi.md#get_zones_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone | Retrieve zones of a model
*IfcApi* | [**launch_new_check_deprecated**](docs/IfcApi.md#launch_new_check_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{id}/launch-check | Launch a new check on the model
*IfcApi* | [**link_documents_of_element_deprecated**](docs/IfcApi.md#link_documents_of_element_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/documents | Link one or many documents to an element
*IfcApi* | [**list_classification_element_relations_deprecated**](docs/IfcApi.md#list_classification_element_relations_deprecated) | **GET** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification-element | List all associations between classifications and elements
*IfcApi* | [**merge_ifcs_deprecated**](docs/IfcApi.md#merge_ifcs_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/merge | Merge IFC files
*IfcApi* | [**optimize_ifc_deprecated**](docs/IfcApi.md#optimize_ifc_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/optimize | Optimize the IFC
*IfcApi* | [**remove_all_element_property_set_deprecated**](docs/IfcApi.md#remove_all_element_property_set_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/all | Remove all property sets from element
*IfcApi* | [**remove_classification_of_element_deprecated**](docs/IfcApi.md#remove_classification_of_element_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/classification/{id} | Remove a classification from an element
*IfcApi* | [**remove_document_of_element_deprecated**](docs/IfcApi.md#remove_document_of_element_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/documents/{id} | Remove a documents from an element
*IfcApi* | [**remove_element_property_set_deprecated**](docs/IfcApi.md#remove_element_property_set_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{id} | Remove a PropertySet from an element
*IfcApi* | [**remove_element_property_set_property_definition_deprecated**](docs/IfcApi.md#remove_element_property_set_property_definition_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{id} | Delete a Definition to a Property
*IfcApi* | [**remove_element_property_set_property_definition_unit_deprecated**](docs/IfcApi.md#remove_element_property_set_property_definition_unit_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit/{id} | Remove a Unit from a Definition
*IfcApi* | [**remove_element_property_set_property_deprecated**](docs/IfcApi.md#remove_element_property_set_property_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Remove a property from a PropertySet
*IfcApi* | [**remove_elements_from_classification_deprecated**](docs/IfcApi.md#remove_elements_from_classification_deprecated) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/classification/{model_classification_pk}/element/{uuid} | Remove the classification from all elements
*IfcApi* | [**reprocess_ifc_deprecated**](docs/IfcApi.md#reprocess_ifc_deprecated) | **POST** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/reprocess | Reprocess Model file
*IfcApi* | [**update_access_token_deprecated**](docs/IfcApi.md#update_access_token_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/access_token/{token} | Update some fields of a token
*IfcApi* | [**update_building_deprecated**](docs/IfcApi.md#update_building_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{uuid} | Update some fields of a building
*IfcApi* | [**update_building_plan_positioning_deprecated**](docs/IfcApi.md#update_building_plan_positioning_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{building_uuid}/plan/{id}/positioning | Update the postioning of the plan in the building
*IfcApi* | [**update_checker_deprecated**](docs/IfcApi.md#update_checker_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{id} | Update some fields of a checker of a model
*IfcApi* | [**update_checker_result_deprecated**](docs/IfcApi.md#update_checker_result_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/checker/{checker_pk}/result/{id} | Update some fields of a CheckerResult
*IfcApi* | [**update_element_deprecated**](docs/IfcApi.md#update_element_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{uuid} | Update some fields of an element
*IfcApi* | [**update_element_property_set_property_deprecated**](docs/IfcApi.md#update_element_property_set_property_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Update a property from an element
*IfcApi* | [**update_ifc_deprecated**](docs/IfcApi.md#update_ifc_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id} | Update some fields of a model
*IfcApi* | [**update_ifc_files_deprecated**](docs/IfcApi.md#update_ifc_files_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{id}/files | Update models file (gltf, svg, structure, etc)
*IfcApi* | [**update_ifc_property_definition_deprecated**](docs/IfcApi.md#update_ifc_property_definition_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertydefinition/{id} | Update some fields of many PropertyDefinitions of a model
*IfcApi* | [**update_ifc_property_deprecated**](docs/IfcApi.md#update_ifc_property_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/property/{id} | Update some fields of a Property
*IfcApi* | [**update_ifc_unit_deprecated**](docs/IfcApi.md#update_ifc_unit_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/unit/{id} | Update some fields of a Unit of a model
*IfcApi* | [**update_layer_deprecated**](docs/IfcApi.md#update_layer_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/layer/{id} | Update some fields of a layer
*IfcApi* | [**update_order_building_plan_deprecated**](docs/IfcApi.md#update_order_building_plan_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/building/{building_uuid}/plan/order | Update order of all plan of a building
*IfcApi* | [**update_order_storey_plan_deprecated**](docs/IfcApi.md#update_order_storey_plan_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{storey_uuid}/plan/order | Update order of all plan of a storey
*IfcApi* | [**update_order_storeys_deprecated**](docs/IfcApi.md#update_order_storeys_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/order | Update order of all storey of a model
*IfcApi* | [**update_processor_handler_deprecated**](docs/IfcApi.md#update_processor_handler_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/processorhandler/{id} | Update the status of a processor handler
*IfcApi* | [**update_property_set_deprecated**](docs/IfcApi.md#update_property_set_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/propertyset/{id} | Update some fields of a PropertySet
*IfcApi* | [**update_space_deprecated**](docs/IfcApi.md#update_space_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/space/{id} | Update some fields of a space
*IfcApi* | [**update_storey_deprecated**](docs/IfcApi.md#update_storey_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{uuid} | Update some fields of a storey
*IfcApi* | [**update_storey_plan_positioning_deprecated**](docs/IfcApi.md#update_storey_plan_positioning_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/storey/{storey_uuid}/plan/{id}/positioning | Update the postioning of the plan in the storey
*IfcApi* | [**update_system_deprecated**](docs/IfcApi.md#update_system_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/system/{uuid} | Update some fields of a system
*IfcApi* | [**update_zone_deprecated**](docs/IfcApi.md#update_zone_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{id} | Update some fields of a zone
*IfcApi* | [**update_zone_space_deprecated**](docs/IfcApi.md#update_zone_space_deprecated) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/ifc/{ifc_pk}/zone/{zone_pk}/space/{id} | Update some fields of a space
*ModelApi* | [**add_model_errors**](docs/ModelApi.md#add_model_errors) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/errors | Add errors to model
*ModelApi* | [**bulk_delete_model_classifications**](docs/ModelApi.md#bulk_delete_model_classifications) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification/list_destroy | Remove all classifications from model&#39;s elements
*ModelApi* | [**bulk_delete_model_properties**](docs/ModelApi.md#bulk_delete_model_properties) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/bulk_destroy | Delete many Property of a model
*ModelApi* | [**bulk_delete_model_property_definitions**](docs/ModelApi.md#bulk_delete_model_property_definitions) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition/bulk_destroy | Delete many PropertyDefinitions of a model
*ModelApi* | [**bulk_delete_model_units**](docs/ModelApi.md#bulk_delete_model_units) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit/bulk_destroy | Delete many Units of a model
*ModelApi* | [**bulk_delete_property_set**](docs/ModelApi.md#bulk_delete_property_set) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset/bulk_destroy | Delete many PropertySet of a model
*ModelApi* | [**bulk_full_update_elements**](docs/ModelApi.md#bulk_full_update_elements) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/bulk_update | Update many elements at once (only changing fields may be defined)
*ModelApi* | [**bulk_full_update_model_property**](docs/ModelApi.md#bulk_full_update_model_property) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/bulk_update | Update some fields of many properties of a model
*ModelApi* | [**bulk_remove_classifications_of_element**](docs/ModelApi.md#bulk_remove_classifications_of_element) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/classification/bulk_destroy | Remove many classifications from an element
*ModelApi* | [**bulk_remove_documents_of_element**](docs/ModelApi.md#bulk_remove_documents_of_element) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/documents/bulk_destroy | Remove many documents from an element
*ModelApi* | [**bulk_remove_elements_from_classification**](docs/ModelApi.md#bulk_remove_elements_from_classification) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification/{model_classification_pk}/element/bulk_destroy | Remove the classifications from all elements
*ModelApi* | [**bulk_update_elements**](docs/ModelApi.md#bulk_update_elements) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/bulk_update | Update many elements at once (all field must be defined)
*ModelApi* | [**bulk_update_model_property**](docs/ModelApi.md#bulk_update_model_property) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/bulk_update | Update all fields of many properties of a model
*ModelApi* | [**create_access_token**](docs/ModelApi.md#create_access_token) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/access_token | Create a token for this model
*ModelApi* | [**create_building**](docs/ModelApi.md#create_building) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building | Create a building of a model
*ModelApi* | [**create_building_plan**](docs/ModelApi.md#create_building_plan) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{building_uuid}/plan/add | Create a relation between a 2d model and a building
*ModelApi* | [**create_classification_element_relations**](docs/ModelApi.md#create_classification_element_relations) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification-element | Create association between existing classification and existing element
*ModelApi* | [**create_classifications_of_element**](docs/ModelApi.md#create_classifications_of_element) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/classification | Create one or many classifications to an element
*ModelApi* | [**create_element**](docs/ModelApi.md#create_element) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element | Create an element in the model
*ModelApi* | [**create_element_property_set**](docs/ModelApi.md#create_element_property_set) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset | Create a PropertySets to an element
*ModelApi* | [**create_element_property_set_property**](docs/ModelApi.md#create_element_property_set_property) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property | Create a property to a PropertySet
*ModelApi* | [**create_element_property_set_property_definition**](docs/ModelApi.md#create_element_property_set_property_definition) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition | Create a Definition to a Property
*ModelApi* | [**create_element_property_set_property_definition_unit**](docs/ModelApi.md#create_element_property_set_property_definition_unit) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit | Create a Unit to a Definition
*ModelApi* | [**create_layer**](docs/ModelApi.md#create_layer) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/layer | Create a layer in the model
*ModelApi* | [**create_meta_building**](docs/ModelApi.md#create_meta_building) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/create-metabuilding | Create an empty 3D Model
*ModelApi* | [**create_model**](docs/ModelApi.md#create_model) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/create-model | Make a PDF or Image file a Model
*ModelApi* | [**create_model_property_definition**](docs/ModelApi.md#create_model_property_definition) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition | Create a PropertyDefinition on the model
*ModelApi* | [**create_model_unit**](docs/ModelApi.md#create_model_unit) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit | Create a Unit on a model
*ModelApi* | [**create_property_set**](docs/ModelApi.md#create_property_set) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset | Create one or many PropertySet
*ModelApi* | [**create_property_set_element_relations**](docs/ModelApi.md#create_property_set_element_relations) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset-element | Create association between PropertySet and element
*ModelApi* | [**create_raw_elements**](docs/ModelApi.md#create_raw_elements) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/raw | Create elements in an optimized format
*ModelApi* | [**create_space**](docs/ModelApi.md#create_space) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/space | Create a space in the model
*ModelApi* | [**create_storey**](docs/ModelApi.md#create_storey) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey | Create a storey of a model
*ModelApi* | [**create_storey_plan**](docs/ModelApi.md#create_storey_plan) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{storey_uuid}/plan/add | Create a relation between a 2d model and a storey
*ModelApi* | [**create_system**](docs/ModelApi.md#create_system) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/system | Create a system in the model
*ModelApi* | [**create_tileset**](docs/ModelApi.md#create_tileset) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/tileset | Create the tileset of the model and upload all files
*ModelApi* | [**create_zone**](docs/ModelApi.md#create_zone) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone | Create a zone in the model
*ModelApi* | [**create_zone_space**](docs/ModelApi.md#create_zone_space) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{zone_pk}/space | Create a space in a zone
*ModelApi* | [**delete_access_token**](docs/ModelApi.md#delete_access_token) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/access_token/{token} | Delete a token
*ModelApi* | [**delete_building**](docs/ModelApi.md#delete_building) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{uuid} | Delete a building of a model
*ModelApi* | [**delete_building_plan**](docs/ModelApi.md#delete_building_plan) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{building_uuid}/plan/{id} | Delete the relation between a 2d model and a building
*ModelApi* | [**delete_element**](docs/ModelApi.md#delete_element) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{uuid} | Delete an element of a model
*ModelApi* | [**delete_layer**](docs/ModelApi.md#delete_layer) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/layer/{id} | Delete a layer of a model
*ModelApi* | [**delete_model**](docs/ModelApi.md#delete_model) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{id} | Delete a model
*ModelApi* | [**delete_model_property**](docs/ModelApi.md#delete_model_property) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/{id} | Delete a Property of a model
*ModelApi* | [**delete_model_property_definition**](docs/ModelApi.md#delete_model_property_definition) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition/{id} | Delete a PropertyDefinitions of a model
*ModelApi* | [**delete_model_unit**](docs/ModelApi.md#delete_model_unit) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit/{id} | Delete a Unit of a model
*ModelApi* | [**delete_model_without_doc**](docs/ModelApi.md#delete_model_without_doc) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/delete-model | Delete the Model without deleting the related document
*ModelApi* | [**delete_property_set**](docs/ModelApi.md#delete_property_set) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset/{id} | Delete a PropertySet of a model
*ModelApi* | [**delete_space**](docs/ModelApi.md#delete_space) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/space/{id} | Delete a space
*ModelApi* | [**delete_storey**](docs/ModelApi.md#delete_storey) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{uuid} | Delete a storey of a model
*ModelApi* | [**delete_storey_plan**](docs/ModelApi.md#delete_storey_plan) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{storey_uuid}/plan/{id} | Delete the relation between a 2d model and a storey
*ModelApi* | [**delete_system**](docs/ModelApi.md#delete_system) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/system/{uuid} | Delete a system of a model
*ModelApi* | [**delete_zone**](docs/ModelApi.md#delete_zone) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{id} | Delete a zone of a model
*ModelApi* | [**delete_zone_space**](docs/ModelApi.md#delete_zone_space) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{zone_pk}/space/{id} | Delete a space of a zone
*ModelApi* | [**export_ifc**](docs/ModelApi.md#export_ifc) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/export | Export IFC
*ModelApi* | [**full_update_element**](docs/ModelApi.md#full_update_element) | **PUT** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{uuid} | Update all fields of an element
*ModelApi* | [**get_access_token**](docs/ModelApi.md#get_access_token) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/access_token/{token} | Retrieve one token created for this model
*ModelApi* | [**get_access_tokens**](docs/ModelApi.md#get_access_tokens) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/access_token | Retrieve all tokens created for this model
*ModelApi* | [**get_building**](docs/ModelApi.md#get_building) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{uuid} | Retrieve a building of a model
*ModelApi* | [**get_building_plan_positioning**](docs/ModelApi.md#get_building_plan_positioning) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{building_uuid}/plan/{id}/positioning | Retrieve the postioning of the plan in the building
*ModelApi* | [**get_buildings**](docs/ModelApi.md#get_buildings) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building | Retrieve all buildings of a model
*ModelApi* | [**get_classifications_of_element**](docs/ModelApi.md#get_classifications_of_element) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/classification | Retrieve all classifications of an element
*ModelApi* | [**get_documents_of_element**](docs/ModelApi.md#get_documents_of_element) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/documents | Retrieve all documents of an element
*ModelApi* | [**get_element**](docs/ModelApi.md#get_element) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{uuid} | Retrieve an element of a model
*ModelApi* | [**get_element_linked_documents**](docs/ModelApi.md#get_element_linked_documents) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/documents | Retrieve all documents linked to any element
*ModelApi* | [**get_element_property_set**](docs/ModelApi.md#get_element_property_set) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{id} | Retrieve a PropertySet of an element
*ModelApi* | [**get_element_property_set_properties**](docs/ModelApi.md#get_element_property_set_properties) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property | Retrieve all Properties of a PropertySet
*ModelApi* | [**get_element_property_set_property**](docs/ModelApi.md#get_element_property_set_property) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Retrieve a Property of a PropertySet
*ModelApi* | [**get_element_property_set_property_definition**](docs/ModelApi.md#get_element_property_set_property_definition) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{id} | Retrieve a Definition of a Property
*ModelApi* | [**get_element_property_set_property_definition_unit**](docs/ModelApi.md#get_element_property_set_property_definition_unit) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit/{id} | Retrieve a Unit of a Definition
*ModelApi* | [**get_element_property_set_property_definition_units**](docs/ModelApi.md#get_element_property_set_property_definition_units) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit | Retrieve all Units of a Definition
*ModelApi* | [**get_element_property_set_property_definitions**](docs/ModelApi.md#get_element_property_set_property_definitions) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition | Retrieve all Definitions of a PropertySet
*ModelApi* | [**get_element_property_sets**](docs/ModelApi.md#get_element_property_sets) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset | Retrieve all PropertySets of an element
*ModelApi* | [**get_elements**](docs/ModelApi.md#get_elements) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element | Retrieve all elements of a model
*ModelApi* | [**get_elements_from_classification**](docs/ModelApi.md#get_elements_from_classification) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification/{model_classification_pk}/element | Retrieve all elements with the classification
*ModelApi* | [**get_layer**](docs/ModelApi.md#get_layer) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/layer/{id} | Retrieve a layer of a model
*ModelApi* | [**get_layers**](docs/ModelApi.md#get_layers) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/layer | Retrieve all layers of a model
*ModelApi* | [**get_material**](docs/ModelApi.md#get_material) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/material/{id} | Retrieve a material of a model
*ModelApi* | [**get_materials**](docs/ModelApi.md#get_materials) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/material | Retrieve all materials of a model
*ModelApi* | [**get_model**](docs/ModelApi.md#get_model) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{id} | Retrieve one model
*ModelApi* | [**get_model_classifications**](docs/ModelApi.md#get_model_classifications) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification | Retrieve all classifications in a model
*ModelApi* | [**get_model_material**](docs/ModelApi.md#get_model_material) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/material/{id} | Retrieve a material of a model
*ModelApi* | [**get_model_materials**](docs/ModelApi.md#get_model_materials) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/material | Retrieve all materials of a model
*ModelApi* | [**get_model_properties**](docs/ModelApi.md#get_model_properties) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property | Retrieve all Properties of a model
*ModelApi* | [**get_model_property**](docs/ModelApi.md#get_model_property) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/{id} | Retrieve a Property of a model
*ModelApi* | [**get_model_property_definition**](docs/ModelApi.md#get_model_property_definition) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition/{id} | Retrieve a PropertyDefinition of a model
*ModelApi* | [**get_model_property_definitions**](docs/ModelApi.md#get_model_property_definitions) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition | Retrieve all PropertyDefinitions of a model
*ModelApi* | [**get_model_unit**](docs/ModelApi.md#get_model_unit) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit/{id} | Retrieve a Unit of a model
*ModelApi* | [**get_model_units**](docs/ModelApi.md#get_model_units) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit | Retrieve all Units of a model
*ModelApi* | [**get_models**](docs/ModelApi.md#get_models) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model | Retrieve all models
*ModelApi* | [**get_processor_handler**](docs/ModelApi.md#get_processor_handler) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/processorhandler/{id} | Retrieve a processor handler
*ModelApi* | [**get_processor_handlers**](docs/ModelApi.md#get_processor_handlers) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/processorhandler | Get all processor handlers
*ModelApi* | [**get_property_set**](docs/ModelApi.md#get_property_set) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset/{id} | Retrieve a PropertySet of a model
*ModelApi* | [**get_property_sets**](docs/ModelApi.md#get_property_sets) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset | Retrieve all PropertySets of a model
*ModelApi* | [**get_raw_elements**](docs/ModelApi.md#get_raw_elements) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/raw | Retrieve all elements in a optimized format
*ModelApi* | [**get_simple_element**](docs/ModelApi.md#get_simple_element) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{uuid}/simple | Retrieve an element of a model with a simple value representation
*ModelApi* | [**get_simple_elements**](docs/ModelApi.md#get_simple_elements) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/simple | Retrieve all elements of a model with a simple value representation
*ModelApi* | [**get_space**](docs/ModelApi.md#get_space) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/space/{id} | Retrieve one space of the model
*ModelApi* | [**get_spaces**](docs/ModelApi.md#get_spaces) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/space | Retrieve all spaces of the model
*ModelApi* | [**get_storey**](docs/ModelApi.md#get_storey) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{uuid} | Retrieve a storey of a model
*ModelApi* | [**get_storey_plan_positioning**](docs/ModelApi.md#get_storey_plan_positioning) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{storey_uuid}/plan/{id}/positioning | Retrieve the postioning of the plan in the storey
*ModelApi* | [**get_storeys**](docs/ModelApi.md#get_storeys) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey | Retrieve all storeys of a model
*ModelApi* | [**get_system**](docs/ModelApi.md#get_system) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/system/{uuid} | Retrieve a system of a model
*ModelApi* | [**get_systems**](docs/ModelApi.md#get_systems) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/system | Retrieve all systems of a model
*ModelApi* | [**get_tileset**](docs/ModelApi.md#get_tileset) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/tileset | Retrieve the tileset of the model
*ModelApi* | [**get_zone**](docs/ModelApi.md#get_zone) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{id} | Retrieve one zone of a model
*ModelApi* | [**get_zone_space**](docs/ModelApi.md#get_zone_space) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{zone_pk}/space/{id} | Retrieve one space of a zone
*ModelApi* | [**get_zone_spaces**](docs/ModelApi.md#get_zone_spaces) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{zone_pk}/space | Retrieve all spaces of a zone
*ModelApi* | [**get_zones**](docs/ModelApi.md#get_zones) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone | Retrieve zones of a model
*ModelApi* | [**link_documents_of_element**](docs/ModelApi.md#link_documents_of_element) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/documents | Link one or many documents to an element
*ModelApi* | [**list_classification_element_relations**](docs/ModelApi.md#list_classification_element_relations) | **GET** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification-element | List all associations between classifications and elements
*ModelApi* | [**merge_ifcs**](docs/ModelApi.md#merge_ifcs) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/merge | Merge IFC files
*ModelApi* | [**optimize_ifc**](docs/ModelApi.md#optimize_ifc) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/optimize | Optimize the IFC
*ModelApi* | [**remove_all_element_property_set**](docs/ModelApi.md#remove_all_element_property_set) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/all | Remove all property sets from element
*ModelApi* | [**remove_classification_of_element**](docs/ModelApi.md#remove_classification_of_element) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/classification/{id} | Remove a classification from an element
*ModelApi* | [**remove_document_of_element**](docs/ModelApi.md#remove_document_of_element) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/documents/{id} | Remove a documents from an element
*ModelApi* | [**remove_element_property_set**](docs/ModelApi.md#remove_element_property_set) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{id} | Remove a PropertySet from an element
*ModelApi* | [**remove_element_property_set_property**](docs/ModelApi.md#remove_element_property_set_property) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Remove a property from a PropertySet
*ModelApi* | [**remove_element_property_set_property_definition**](docs/ModelApi.md#remove_element_property_set_property_definition) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{id} | Delete a Definition to a Property
*ModelApi* | [**remove_element_property_set_property_definition_unit**](docs/ModelApi.md#remove_element_property_set_property_definition_unit) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{property_pk}/propertydefinition/{propertydefinition_pk}/unit/{id} | Remove a Unit from a Definition
*ModelApi* | [**remove_elements_from_classification**](docs/ModelApi.md#remove_elements_from_classification) | **DELETE** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/classification/{model_classification_pk}/element/{uuid} | Remove the classification from all elements
*ModelApi* | [**reprocess_model**](docs/ModelApi.md#reprocess_model) | **POST** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/reprocess | Reprocess Model file
*ModelApi* | [**update_access_token**](docs/ModelApi.md#update_access_token) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/access_token/{token} | Update some fields of a token
*ModelApi* | [**update_building**](docs/ModelApi.md#update_building) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{uuid} | Update some fields of a building
*ModelApi* | [**update_building_plan_positioning**](docs/ModelApi.md#update_building_plan_positioning) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{building_uuid}/plan/{id}/positioning | Update the postioning of the plan in the building
*ModelApi* | [**update_element**](docs/ModelApi.md#update_element) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{uuid} | Update some fields of an element
*ModelApi* | [**update_element_property_set_property**](docs/ModelApi.md#update_element_property_set_property) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/element/{element_uuid}/propertyset/{propertyset_pk}/property/{id} | Update a property from an element
*ModelApi* | [**update_layer**](docs/ModelApi.md#update_layer) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/layer/{id} | Update some fields of a layer
*ModelApi* | [**update_model**](docs/ModelApi.md#update_model) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{id} | Update some fields of a model
*ModelApi* | [**update_model_files**](docs/ModelApi.md#update_model_files) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{id}/files | Update models file (gltf, svg, structure, etc)
*ModelApi* | [**update_model_property**](docs/ModelApi.md#update_model_property) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/property/{id} | Update some fields of a Property
*ModelApi* | [**update_model_property_definition**](docs/ModelApi.md#update_model_property_definition) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertydefinition/{id} | Update some fields of many PropertyDefinitions of a model
*ModelApi* | [**update_model_unit**](docs/ModelApi.md#update_model_unit) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/unit/{id} | Update some fields of a Unit of a model
*ModelApi* | [**update_order_building_plan**](docs/ModelApi.md#update_order_building_plan) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/building/{building_uuid}/plan/order | Update order of all plan of a building
*ModelApi* | [**update_order_storey_plan**](docs/ModelApi.md#update_order_storey_plan) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{storey_uuid}/plan/order | Update order of all plan of a storey
*ModelApi* | [**update_order_storeys**](docs/ModelApi.md#update_order_storeys) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/order | Update order of all storey of a model
*ModelApi* | [**update_processor_handler**](docs/ModelApi.md#update_processor_handler) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/processorhandler/{id} | Update the status of a processor handler
*ModelApi* | [**update_property_set**](docs/ModelApi.md#update_property_set) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/propertyset/{id} | Update some fields of a PropertySet
*ModelApi* | [**update_space**](docs/ModelApi.md#update_space) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/space/{id} | Update some fields of a space
*ModelApi* | [**update_storey**](docs/ModelApi.md#update_storey) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{uuid} | Update some fields of a storey
*ModelApi* | [**update_storey_plan_positioning**](docs/ModelApi.md#update_storey_plan_positioning) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/storey/{storey_uuid}/plan/{id}/positioning | Update the postioning of the plan in the storey
*ModelApi* | [**update_system**](docs/ModelApi.md#update_system) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/system/{uuid} | Update some fields of a system
*ModelApi* | [**update_zone**](docs/ModelApi.md#update_zone) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{id} | Update some fields of a zone
*ModelApi* | [**update_zone_space**](docs/ModelApi.md#update_zone_space) | **PATCH** /cloud/{cloud_pk}/project/{project_pk}/model/{model_pk}/zone/{zone_pk}/space/{id} | Update some fields of a space
*SsoApi* | [**accept_invitation**](docs/SsoApi.md#accept_invitation) | **POST** /identity-provider/invitation/{id}/accept | Accept an invitation
*SsoApi* | [**delete_user**](docs/SsoApi.md#delete_user) | **DELETE** /identity-provider/user | Delete user from BIMData
*SsoApi* | [**deny_invitation**](docs/SsoApi.md#deny_invitation) | **POST** /identity-provider/invitation/{id}/deny | Deny an invitation
*SsoApi* | [**get_invitation**](docs/SsoApi.md#get_invitation) | **GET** /identity-provider/invitation/{id} | Retrieve an invitation
*SsoApi* | [**get_invitations**](docs/SsoApi.md#get_invitations) | **GET** /identity-provider/invitation | Retrieve all invitations
*WebhookApi* | [**create_web_hook**](docs/WebhookApi.md#create_web_hook) | **POST** /cloud/{cloud_pk}/webhook | Create a new Webhook
*WebhookApi* | [**delete_web_hook**](docs/WebhookApi.md#delete_web_hook) | **DELETE** /cloud/{cloud_pk}/webhook/{id} | Delete a webhook
*WebhookApi* | [**get_web_hook**](docs/WebhookApi.md#get_web_hook) | **GET** /cloud/{cloud_pk}/webhook/{id} | Retrieve one configured webhook
*WebhookApi* | [**get_web_hooks**](docs/WebhookApi.md#get_web_hooks) | **GET** /cloud/{cloud_pk}/webhook | Retrieve all configured webhooks
*WebhookApi* | [**ping_web_hook**](docs/WebhookApi.md#ping_web_hook) | **POST** /cloud/{cloud_pk}/webhook/{id}/ping | Test a webhook
*WebhookApi* | [**update_web_hook**](docs/WebhookApi.md#update_web_hook) | **PATCH** /cloud/{cloud_pk}/webhook/{id} | Update some field of a webhook


## Documentation For Models

 - [BcfProject](docs/BcfProject.md)
 - [BcfProjectRequest](docs/BcfProjectRequest.md)
 - [Building](docs/Building.md)
 - [BuildingModelPlanRequest](docs/BuildingModelPlanRequest.md)
 - [CheckPlan](docs/CheckPlan.md)
 - [CheckPlanRequest](docs/CheckPlanRequest.md)
 - [CheckerResult](docs/CheckerResult.md)
 - [CheckerResultRequest](docs/CheckerResultRequest.md)
 - [Classification](docs/Classification.md)
 - [ClassificationRequest](docs/ClassificationRequest.md)
 - [ClippingPlane](docs/ClippingPlane.md)
 - [ClippingPlaneRequest](docs/ClippingPlaneRequest.md)
 - [Cloud](docs/Cloud.md)
 - [CloudInvitation](docs/CloudInvitation.md)
 - [CloudInvitationRequest](docs/CloudInvitationRequest.md)
 - [CloudRequest](docs/CloudRequest.md)
 - [CloudRole](docs/CloudRole.md)
 - [Coloring](docs/Coloring.md)
 - [ColoringRequest](docs/ColoringRequest.md)
 - [Comment](docs/Comment.md)
 - [CommentRequest](docs/CommentRequest.md)
 - [Component](docs/Component.md)
 - [ComponentRequest](docs/ComponentRequest.md)
 - [ComponentsParent](docs/ComponentsParent.md)
 - [ComponentsParentRequest](docs/ComponentsParentRequest.md)
 - [CreateBuildingByNameRequest](docs/CreateBuildingByNameRequest.md)
 - [CreateModelRequest](docs/CreateModelRequest.md)
 - [DetailedExtensions](docs/DetailedExtensions.md)
 - [Direction](docs/Direction.md)
 - [DirectionRequest](docs/DirectionRequest.md)
 - [Document](docs/Document.md)
 - [DocumentWithElementList](docs/DocumentWithElementList.md)
 - [Element](docs/Element.md)
 - [ElementClassificationRelation](docs/ElementClassificationRelation.md)
 - [ElementClassificationRelationRequest](docs/ElementClassificationRelationRequest.md)
 - [ElementPropertySetRelationRequest](docs/ElementPropertySetRelationRequest.md)
 - [ElementRequest](docs/ElementRequest.md)
 - [Extensions](docs/Extensions.md)
 - [Feature](docs/Feature.md)
 - [FeatureRequest](docs/FeatureRequest.md)
 - [Folder](docs/Folder.md)
 - [FolderGroupPermission](docs/FolderGroupPermission.md)
 - [FolderGroupPermissionRequest](docs/FolderGroupPermissionRequest.md)
 - [FolderTree](docs/FolderTree.md)
 - [FolderUserProject](docs/FolderUserProject.md)
 - [FolderWithoutChildren](docs/FolderWithoutChildren.md)
 - [FolderWithoutChildrenRequest](docs/FolderWithoutChildrenRequest.md)
 - [FullTopic](docs/FullTopic.md)
 - [FullTopicRequest](docs/FullTopicRequest.md)
 - [Group](docs/Group.md)
 - [GroupFolder](docs/GroupFolder.md)
 - [GroupRequest](docs/GroupRequest.md)
 - [IfcAccessToken](docs/IfcAccessToken.md)
 - [IfcAccessTokenRequest](docs/IfcAccessTokenRequest.md)
 - [IfcChecker](docs/IfcChecker.md)
 - [IfcCheckerRequest](docs/IfcCheckerRequest.md)
 - [IfcExport](docs/IfcExport.md)
 - [IfcExportRequest](docs/IfcExportRequest.md)
 - [IfcMergeRequest](docs/IfcMergeRequest.md)
 - [IfcOptimizeRequest](docs/IfcOptimizeRequest.md)
 - [Invitation](docs/Invitation.md)
 - [Label](docs/Label.md)
 - [LabelRequest](docs/LabelRequest.md)
 - [Layer](docs/Layer.md)
 - [LayerElement](docs/LayerElement.md)
 - [LayerElementRequest](docs/LayerElementRequest.md)
 - [LayerRequest](docs/LayerRequest.md)
 - [Line](docs/Line.md)
 - [LineRequest](docs/LineRequest.md)
 - [MarketplaceApp](docs/MarketplaceApp.md)
 - [MarketplaceAppImage](docs/MarketplaceAppImage.md)
 - [MarketplaceAppImageRequest](docs/MarketplaceAppImageRequest.md)
 - [MarketplaceAppRequest](docs/MarketplaceAppRequest.md)
 - [Material](docs/Material.md)
 - [MaterialListComponent](docs/MaterialListComponent.md)
 - [MaterialListComponentRequest](docs/MaterialListComponentRequest.md)
 - [MaterialOption](docs/MaterialOption.md)
 - [MaterialRequest](docs/MaterialRequest.md)
 - [Model](docs/Model.md)
 - [ModelErrors](docs/ModelErrors.md)
 - [ModelErrorsRequest](docs/ModelErrorsRequest.md)
 - [ModelFiles](docs/ModelFiles.md)
 - [ModelProperty](docs/ModelProperty.md)
 - [ModelRequest](docs/ModelRequest.md)
 - [ModelWithPositioningPlan](docs/ModelWithPositioningPlan.md)
 - [Organization](docs/Organization.md)
 - [OrganizationRequest](docs/OrganizationRequest.md)
 - [OrthogonalCamera](docs/OrthogonalCamera.md)
 - [OrthogonalCameraRequest](docs/OrthogonalCameraRequest.md)
 - [PatchedBcfProjectRequest](docs/PatchedBcfProjectRequest.md)
 - [PatchedCheckPlanRequest](docs/PatchedCheckPlanRequest.md)
 - [PatchedCheckerResultRequest](docs/PatchedCheckerResultRequest.md)
 - [PatchedClassificationRequest](docs/PatchedClassificationRequest.md)
 - [PatchedCloudRequest](docs/PatchedCloudRequest.md)
 - [PatchedCommentRequest](docs/PatchedCommentRequest.md)
 - [PatchedDocumentRequest](docs/PatchedDocumentRequest.md)
 - [PatchedElementRequest](docs/PatchedElementRequest.md)
 - [PatchedFolderWithoutChildrenRequest](docs/PatchedFolderWithoutChildrenRequest.md)
 - [PatchedFullTopicRequest](docs/PatchedFullTopicRequest.md)
 - [PatchedGroupFolderRequest](docs/PatchedGroupFolderRequest.md)
 - [PatchedGroupRequest](docs/PatchedGroupRequest.md)
 - [PatchedIfcAccessTokenRequest](docs/PatchedIfcAccessTokenRequest.md)
 - [PatchedIfcCheckerRequest](docs/PatchedIfcCheckerRequest.md)
 - [PatchedLabelRequest](docs/PatchedLabelRequest.md)
 - [PatchedLayerRequest](docs/PatchedLayerRequest.md)
 - [PatchedModelRequest](docs/PatchedModelRequest.md)
 - [PatchedPositioningPlanRequest](docs/PatchedPositioningPlanRequest.md)
 - [PatchedPriorityRequest](docs/PatchedPriorityRequest.md)
 - [PatchedProcessorHandlerRequest](docs/PatchedProcessorHandlerRequest.md)
 - [PatchedProjectAccessTokenRequest](docs/PatchedProjectAccessTokenRequest.md)
 - [PatchedProjectRequest](docs/PatchedProjectRequest.md)
 - [PatchedPropertyDefinitionRequest](docs/PatchedPropertyDefinitionRequest.md)
 - [PatchedPropertyRequest](docs/PatchedPropertyRequest.md)
 - [PatchedPropertySetRequest](docs/PatchedPropertySetRequest.md)
 - [PatchedRuleComponentRequest](docs/PatchedRuleComponentRequest.md)
 - [PatchedRuleRequest](docs/PatchedRuleRequest.md)
 - [PatchedRulesetRequest](docs/PatchedRulesetRequest.md)
 - [PatchedSpaceRequest](docs/PatchedSpaceRequest.md)
 - [PatchedStageRequest](docs/PatchedStageRequest.md)
 - [PatchedStoreyBuildingRequest](docs/PatchedStoreyBuildingRequest.md)
 - [PatchedSystemRequest](docs/PatchedSystemRequest.md)
 - [PatchedTagRequest](docs/PatchedTagRequest.md)
 - [PatchedTopicRequest](docs/PatchedTopicRequest.md)
 - [PatchedTopicStatusRequest](docs/PatchedTopicStatusRequest.md)
 - [PatchedTopicTypeRequest](docs/PatchedTopicTypeRequest.md)
 - [PatchedUnitRequest](docs/PatchedUnitRequest.md)
 - [PatchedUserCloudUpdateRequest](docs/PatchedUserCloudUpdateRequest.md)
 - [PatchedUserProjectUpdateRequest](docs/PatchedUserProjectUpdateRequest.md)
 - [PatchedViewpointRequest](docs/PatchedViewpointRequest.md)
 - [PatchedVisaCommentRequest](docs/PatchedVisaCommentRequest.md)
 - [PatchedVisaRequest](docs/PatchedVisaRequest.md)
 - [PatchedVisaValidationRequest](docs/PatchedVisaValidationRequest.md)
 - [PatchedWebHookRequest](docs/PatchedWebHookRequest.md)
 - [PatchedZoneRequest](docs/PatchedZoneRequest.md)
 - [PatchedZoneSpaceRequest](docs/PatchedZoneSpaceRequest.md)
 - [PerspectiveCamera](docs/PerspectiveCamera.md)
 - [PerspectiveCameraRequest](docs/PerspectiveCameraRequest.md)
 - [Pin](docs/Pin.md)
 - [PinRequest](docs/PinRequest.md)
 - [Point](docs/Point.md)
 - [PointRequest](docs/PointRequest.md)
 - [PositioningPlan](docs/PositioningPlan.md)
 - [Priority](docs/Priority.md)
 - [PriorityRequest](docs/PriorityRequest.md)
 - [ProcessorHandler](docs/ProcessorHandler.md)
 - [Project](docs/Project.md)
 - [ProjectAccessToken](docs/ProjectAccessToken.md)
 - [ProjectAccessTokenRequest](docs/ProjectAccessTokenRequest.md)
 - [ProjectFolderTree](docs/ProjectFolderTree.md)
 - [ProjectInvitation](docs/ProjectInvitation.md)
 - [ProjectInvitationRequest](docs/ProjectInvitationRequest.md)
 - [ProjectRequest](docs/ProjectRequest.md)
 - [ProjectRole](docs/ProjectRole.md)
 - [ProjectSize](docs/ProjectSize.md)
 - [ProjectWithChildren](docs/ProjectWithChildren.md)
 - [PropertyDefinition](docs/PropertyDefinition.md)
 - [PropertyDefinitionRequest](docs/PropertyDefinitionRequest.md)
 - [PropertyRequest](docs/PropertyRequest.md)
 - [PropertySet](docs/PropertySet.md)
 - [PropertySetRequest](docs/PropertySetRequest.md)
 - [PublicOrganization](docs/PublicOrganization.md)
 - [PublicOrganizationRequest](docs/PublicOrganizationRequest.md)
 - [RawClassification](docs/RawClassification.md)
 - [RawClassificationRequest](docs/RawClassificationRequest.md)
 - [RawDefinition](docs/RawDefinition.md)
 - [RawDefinitionRequest](docs/RawDefinitionRequest.md)
 - [RawElement](docs/RawElement.md)
 - [RawElementRequest](docs/RawElementRequest.md)
 - [RawElements](docs/RawElements.md)
 - [RawElementsRequest](docs/RawElementsRequest.md)
 - [RawLayer](docs/RawLayer.md)
 - [RawLayerRequest](docs/RawLayerRequest.md)
 - [RawMaterial](docs/RawMaterial.md)
 - [RawMaterialList](docs/RawMaterialList.md)
 - [RawMaterialListComponents](docs/RawMaterialListComponents.md)
 - [RawMaterialListComponentsRequest](docs/RawMaterialListComponentsRequest.md)
 - [RawMaterialListRequest](docs/RawMaterialListRequest.md)
 - [RawMaterialOptions](docs/RawMaterialOptions.md)
 - [RawMaterialOptionsRequest](docs/RawMaterialOptionsRequest.md)
 - [RawMaterialRequest](docs/RawMaterialRequest.md)
 - [RawProperty](docs/RawProperty.md)
 - [RawPropertyRequest](docs/RawPropertyRequest.md)
 - [RawPropertySet](docs/RawPropertySet.md)
 - [RawPropertySetRequest](docs/RawPropertySetRequest.md)
 - [RawSystem](docs/RawSystem.md)
 - [RawSystemRequest](docs/RawSystemRequest.md)
 - [RawUnit](docs/RawUnit.md)
 - [RawUnitRequest](docs/RawUnitRequest.md)
 - [RecursiveFolderChildren](docs/RecursiveFolderChildren.md)
 - [Rule](docs/Rule.md)
 - [RuleComponent](docs/RuleComponent.md)
 - [RuleComponentRequest](docs/RuleComponentRequest.md)
 - [RuleRequest](docs/RuleRequest.md)
 - [Ruleset](docs/Ruleset.md)
 - [RulesetRequest](docs/RulesetRequest.md)
 - [SelfBcfUser](docs/SelfBcfUser.md)
 - [SelfUser](docs/SelfUser.md)
 - [SimpleElement](docs/SimpleElement.md)
 - [Size](docs/Size.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotRequest](docs/SnapshotRequest.md)
 - [Space](docs/Space.md)
 - [SpaceRequest](docs/SpaceRequest.md)
 - [Stage](docs/Stage.md)
 - [StageRequest](docs/StageRequest.md)
 - [Storey](docs/Storey.md)
 - [StoreyBuildingRequest](docs/StoreyBuildingRequest.md)
 - [StoreyModelPlanRequest](docs/StoreyModelPlanRequest.md)
 - [System](docs/System.md)
 - [SystemRequest](docs/SystemRequest.md)
 - [Tag](docs/Tag.md)
 - [TagIdRequest](docs/TagIdRequest.md)
 - [TagRequest](docs/TagRequest.md)
 - [Topic](docs/Topic.md)
 - [TopicRequest](docs/TopicRequest.md)
 - [TopicStatus](docs/TopicStatus.md)
 - [TopicStatusRequest](docs/TopicStatusRequest.md)
 - [TopicType](docs/TopicType.md)
 - [TopicTypeRequest](docs/TopicTypeRequest.md)
 - [Unit](docs/Unit.md)
 - [UnitRequest](docs/UnitRequest.md)
 - [User](docs/User.md)
 - [UserInvitation](docs/UserInvitation.md)
 - [UserProject](docs/UserProject.md)
 - [UserProjectIdRequest](docs/UserProjectIdRequest.md)
 - [ViewSetupHints](docs/ViewSetupHints.md)
 - [ViewSetupHintsRequest](docs/ViewSetupHintsRequest.md)
 - [Viewpoint](docs/Viewpoint.md)
 - [ViewpointRequest](docs/ViewpointRequest.md)
 - [Visa](docs/Visa.md)
 - [VisaComment](docs/VisaComment.md)
 - [VisaCommentRequest](docs/VisaCommentRequest.md)
 - [VisaRequest](docs/VisaRequest.md)
 - [VisaValidation](docs/VisaValidation.md)
 - [VisaValidationRequest](docs/VisaValidationRequest.md)
 - [Visibility](docs/Visibility.md)
 - [VisibilityRequest](docs/VisibilityRequest.md)
 - [WebHook](docs/WebHook.md)
 - [WebHookRequest](docs/WebHookRequest.md)
 - [WriteFolderRequest](docs/WriteFolderRequest.md)
 - [Zone](docs/Zone.md)
 - [ZoneRequest](docs/ZoneRequest.md)
 - [ZoneSpace](docs/ZoneSpace.md)
 - [ZoneSpaceRequest](docs/ZoneSpaceRequest.md)


## Documentation For Authorization


## ApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## BIMData_Connect

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: http://fakeurl.bimdata.io/realms/bimdata/protocol/openid-connect/auth
- **Scopes**: N/A


## BIMData_Connect

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@bimdata.io


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in bimdata_api_client.apis and bimdata_api_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from bimdata_api_client.api.default_api import DefaultApi`
- `from bimdata_api_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import bimdata_api_client
from bimdata_api_client.apis import *
from bimdata_api_client.models import *
```

